==> scap-security-guide_0.1.76.orig.tar.gz: content-0.1.76/docs/manual/user/30_content_notes.md <==
# Content Notes

## Deprecated Content
Below is list of products that have been removed from the project.

| Product                                      | EOL Date           | Last Release                                                                       |
|----------------------------------------------|--------------------|------------------------------------------------------------------------------------|
| Debian 8                                     | June 30, 2020      | [content 0.1.52](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.52) |
| Debian 9                                     | June 30, 2022      | [content 0.1.65](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.65) |
| Debian 10                                    | June 30, 2024      | [content 0.1.73](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.73) |
| Java Runtime Environment                     | -                  | [content 0.1.64](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.64) |
| JBoss EAP 5                                  | November 30, 2016  | [content 0.1.35](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.35) |
| JBoss EAP 6                                  | June 30, 2019      | [content 0.1.53](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.53) |
| JBoss Fuse 6                                 | January 1, 2022    | [content 0.1.64](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.64) |
| McAfee VirusScan Enterprise for Linux (VESL) | December 31, 2021  | [content 0.1.65](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.65) |
| Red Hat Enterprise Linux 5                   | March 31, 2017     | [content 0.1.34](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.34) |
| Red Hat Enterprise Linux 6                   | June 1, 2022       | [content 0.1.52](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.52) |
| Red Hat Enterprise Linux 7                   | June 31, 2024      | [content 0.1.73](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.73) |
| Red Hat Enterprise Virtualization Manager 3  | September 30, 2018 | [content 0.1.38](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.38) |
| Red Hat OpenShift Container Platform 3       | June 1, 2022       | [content 0.1.52](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.52) |
| Red Hat OpenStack Platform 7                 | August 5, 2018     | [content 0.1.41](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.41) |
| SUSE Enterprise Linux 11                     | March 31, 2019     | [content 0.1.52](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.52) |
| Ubuntu 14.04                                 | April 30, 2019     | [content 0.1.52](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.52) |
| UnionTech OS Server 20                       | -                  | [content 0.1.74](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.74) |
| Webmin                                       | -                  | [content 0.1.38](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.38) |
| Wind River Linux 1019                        | -                  | [content 0.1.63](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.63) |
| Wind River Linux 8                           | -                  | [content 0.1.63](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.63) |

==> scap-security-guide_0.1.78.orig.tar.gz: content-0.1.78/docs/manual/user/30_content_notes.md <==
# Content Notes

## Deprecated Content
Below is list of products that have been removed from the project.

| Product                                      | EOL Date           | Last Release                                                                       |
|----------------------------------------------|--------------------|------------------------------------------------------------------------------------|
| Apple macOS 10.15                            | -                  | [content 0.1.76](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.76) |
| Debian 8                                     | June 30, 2020      | [content 0.1.52](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.52) |
| Debian 9                                     | June 30, 2022      | [content 0.1.65](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.65) |
| Debian 10                                    | June 30, 2024      | [content 0.1.73](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.73) |
| Java Runtime Environment                     | -                  | [content 0.1.64](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.64) |
| JBoss EAP 5                                  | November 30, 2016  | [content 0.1.35](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.35) |
| JBoss EAP 6                                  | June 30, 2019      | [content 0.1.53](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.53) |
| JBoss Fuse 6                                 | January 1, 2022    | [content 0.1.64](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.64) |
| McAfee VirusScan Enterprise for Linux (VESL) | December 31, 2021  | [content 0.1.65](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.65) |
| Red Hat Enterprise Linux 5                   | March 31, 2017     | [content 0.1.34](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.34) |
| Red Hat Enterprise Linux 6                   | June 1, 2022       | [content 0.1.52](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.52) |
| Red Hat Enterprise Linux 7                   | June 31, 2024      | [content 0.1.73](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.73) |
| Red Hat Enterprise Virtualization Manager 3  | September 30, 2018 | [content 0.1.38](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.38) |
| Red Hat OpenShift Container Platform 3       | June 1, 2022       | [content 0.1.52](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.52) |
| Red Hat OpenStack Platform 7                 | August 5, 2018     | [content 0.1.41](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.41) |
| SUSE Enterprise Linux 11                     | March 31, 2019     | [content 0.1.52](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.52) |
| Ubuntu 14.04                                 | April 30, 2019     | [content 0.1.52](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.52) |
| Ubuntu 16.04                                 | April 30, 2021     | [content 0.1.77](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.77) |
| Ubuntu 18.04                                 | May 30, 2023       | [content 0.1.77](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.77) |
| Ubuntu 20.04                                 | May 30, 2025       | [content 0.1.77](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.77) |
| UnionTech OS Server 20                       | -                  | [content 0.1.74](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.74) |
| Webmin                                       | -                  | [content 0.1.38](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.38) |
| Wind River Linux 1019                        | -                  | [content 0.1.63](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.63) |
| Wind River Linux 8                           | -                  | [content 0.1.63](https://github.com/ComplianceAsCode/content/releases/tag/v0.1.63) |
